@@ -1,8 +1,7 @@
-
 module Blank
-  def self.included base
+  def self.included(base)
     base.class_eval do
       instance_methods.each { |m| undef_method m unless m =~ /^__|object_id/ }
     end
   end
-end
\ No newline at end of file
+end
