@@ -1,11 +1,8 @@
-require 'commander'
-require 'commander/methods'
-
 module Commander
   def configure(*configuration_opts, &configuration_block)
     configuration_module = Module.new
     configuration_module.extend Commander::Methods
-    
+
     configuration_module.class_exec(*configuration_opts, &configuration_block)
 
     configuration_module.class_exec do
@@ -15,4 +12,3 @@ module Commander
 
   module_function :configure
 end
-
