@@ -335,9 +335,11 @@ module Commander
           switches.map! { |s| s[0, s.index('=') || s.index(' ') || s.length] }
         end
 
+        switches = expand_optionally_negative_switches(switches)
+
         past_switch, arg_removed = false, false
         args.delete_if do |arg|
-          if switches.any? { |s| arg[0, s.length] == s }
+          if switches.any? { |s| s[0, arg.length] == arg }
             arg_removed = !switch_has_arg
             past_switch = true
           elsif past_switch && !arg_removed && arg !~ /^-/
@@ -350,6 +352,20 @@ module Commander
       end
     end
 
+    # expand switches of the style '--[no-]blah' into both their
+    # '--blah' and '--no-blah' variants, so that they can be
+    # properly detected and removed
+    def expand_optionally_negative_switches(switches)
+      switches.reduce([]) do |memo, val|
+        if val =~ /\[no-\]/
+          memo << val.gsub(/\[no-\]/, '')
+          memo << val.gsub(/\[no-\]/, 'no-')
+        else
+          memo << val
+        end
+      end
+    end
+
     ##
     # Parse global command options.
 
