@@ -110,6 +110,28 @@ describe Commander do
       end.run!
       expect(quiet).to be true
     end
+
+    it 'should be inherited by commands when the positive form of a [no-] option' do
+      quiet = nil
+      new_command_runner 'foo', '--quiet' do
+        global_option('--[no-]quiet', 'Suppress output') {}
+        command :foo do |c|
+          c.when_called { |_, options| quiet = options.quiet }
+        end
+      end.run!
+      expect(quiet).to be true
+    end
+
+    it 'should be inherited by commands when the negative form of a [no-] option' do
+      quiet = nil
+      new_command_runner 'foo', '--no-quiet' do
+        global_option('--[no-]quiet', 'Suppress output') {}
+        command :foo do |c|
+          c.when_called { |_, options| quiet = options.quiet }
+        end
+      end.run!
+      expect(quiet).to be false
+    end
   end
 
   describe '#parse_global_options' do
@@ -270,6 +292,40 @@ describe Commander do
       command_runner.remove_global_options options, args
       expect(args).to eq(%w(alpha beta))
     end
+
+    it 'should remove a switch that is the positive form of the [no-] option' do
+      options, args = [], []
+      options << { switches: ['-g', '--[no-]good'] }
+      options << { switches: ['-y', '--yes ARG'] }
+      options << { switches: ['-a', '--alternative=ARG'] }
+      args << '--good' << 'alpha'
+      args << '--yes' << 'deleted'
+      args << '-a' << 'deleted'
+      args << 'beta'
+      command_runner.remove_global_options options, args
+      expect(args).to eq(%w(alpha beta))
+    end
+
+    it 'should remove a switch that is the negative form of the [no-] option' do
+      options, args = [], []
+      options << { switches: ['-g', '--[no-]good'] }
+      options << { switches: ['-y', '--yes ARG'] }
+      options << { switches: ['-a', '--alternative=ARG'] }
+      args << '--no-good' << 'alpha'
+      args << '--yes' << 'deleted'
+      args << '-a' << 'deleted'
+      args << 'beta'
+      command_runner.remove_global_options options, args
+      expect(args).to eq(%w(alpha beta))
+    end
+
+    it 'should not remove options that start with a global option name' do
+      options, args = [], []
+      options << { switches: ['-v', '--version'] }
+      args << '--versionCode' << 'something'
+      command_runner.remove_global_options options, args
+      expect(args).to eq(%w(--versionCode something))
+    end
   end
 
   describe '--trace' do
